#!/bin/perl -w
#################################################################################
# Created       : Martin Foster
# Modified      : 01/17/2000
#################################################################################
#
# Text Configuration - Script part of Webchat designed to modify documents on database
# Copyright (C) 2000  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : mfoster@redwhite.com
#       Address : Suite 209 - 355 5th Ave NE
#                 Calgary, Alberta
#                 T2R 0K9
#
#################################################################################
use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use Webchat::Database;						# Database handler
use Webchat::Dbm;						# DBM Addition
use Webchat::Login;						# Login functionality
use Webchat::Param;						# Parameter control

#################################################################################
# Data Members
#################################################################################
my $Database;							# Database handle
my $cgi;							# Common gateway interface handle

my %config;							# System hash
my %param;							# Parameter hash


#################################################################################
# Program Area
#################################################################################

	$cgi = new CGI;						# Create CGI Handle

	Webchat::Database::DatabaseConnect(\$Database);		# Connect to MySQL
	Webchat::Param::GetParam($cgi, \%param);		# Retreive parameters

	print $cgi->header();					# File header
	print $cgi->start_html('Document Administration');	# HTML header			

	# Login
	if (Webchat::Login::GetVerificationAdmin($Database, $cgi, \%param))
	{
		print $cgi->h1('Document Administration'), "\n";# Document title

		# If no DOCTYPE then list options 
		if (!defined($param{'DOCTYPE'}))
		{ DocumentSelect($Database, $cgi, \%param); }			
	
		# If only DOCTYPE is specified then allow to modify
		elsif ((defined($param{'DOCTYPE'})) && (!defined($param{'DOCDATA'})))
		{
			DocumentSelect($Database, $cgi, \%param);
			DocumentModify($Database, $cgi, \%param); 		
		}

		# If only DOCTYPE and DOCDATA are specified
		elsif ((defined($param{'DOCTYPE'})) && (defined($param{'DOCDATA'})))
		{
			DocumentSelect($Database, $cgi, \%param);
			DocumentModify($Database, $cgi, \%param); 		
		}
	}
	print $cgi->end_html();					# HTML footer
	$Database->disconnect();				# Disconnect from database


#################################################################################
# Sub-Routines
#################################################################################

#####################
# Document Modify
#
# Simply modifies documents available and allows one to select them.

sub DocumentModify						# Database, CGI
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $Statement;						# Statement shift

	my $cgi = shift;					# CGI handle
	my $param = shift;					# Parameter list

	my $document;						# Document
	

	#####################
	# Program area	
	
	# If defined save
	if (defined($param->{'DOCDATA'}))
	{
		$Database->do("UPDATE WebchatText SET WebchatTextContent=? WHERE WebchatTextName=?",
			{},  $param->{'DOCDATA'}, $param->{'DOCTYPE'});
	}

	# Prepare and execute statement
	$Statement = $Database->prepare("SELECT WebchatTextContent FROM WebchatText
					WHERE WebchatTextName='$param->{'DOCTYPE'}'");
	$Statement->execute();

	# Retreive and finish
	$document = $Statement->fetchrow();
	$Statement->finish();

	print $cgi->start_form();

	# Display HTML and information
	print "\t<B>Opened document</B>\n\t<BR>\n";
	print "\t", $cgi->textarea('DOCDATA', $document, 15, 100), "\n";

	# Embed information
	Webchat::Param::EmbedNormal($Database, $cgi, $param);
	print "\t", $cgi->hidden('DOCTYPE', $param->{'DOCTYPE'}), "\n"; 

	print "\t", $cgi->p($cgi->submit('Save Changes')), "\n";
	print $cgi->end_form(), "\n";
}


#####################
# DocumentSelect
#
# Simply lists documents available and allows one to select them.

sub DocumentSelect						# Database, CGI
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $cgi = shift;					# CGI handle
	my $param = shift;					# Parameter list

	my @list;						# List of fields


	#####################
	# Program area

	# Retrieve list of documents
	Webchat::Database::GetListDocuments($Database, \@list);
		
	print "\t", $cgi->hr, "\n";				# Horizontal row
	print $cgi->start_form();				# Begnning HTML form

	# Prompt and Display Document choices
	print "\t", $cgi->p('Document list: ', $cgi->popup_menu('DOCTYPE', \@list)), "\n";
	print "\t", $cgi->p($cgi->submit('Open Document')), "\n";

	Webchat::Param::EmbedNormal($Database, $cgi, $param);

	print $cgi->end_form(), "\n";				# Ending HTML form
	print "\t", $cgi->hr, "\n";				# Horizontal row
}
